==> haskell-yesod-core-1.4.19-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-core/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.4.19
id: yesod-core-1.4.19-f58e956f86f9387c891d6fa112ae88e5
key: yesod_Bp2F0GAVAou0VuJBSPbCQH
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Json Yesod.Core.Widget
    Yesod.Core.Internal Yesod.Core.Types Yesod.Core.Unsafe
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.19
hs-libraries: HSyesod-core-1.4.19-Bp2F0GAVAou0VuJBSPbCQH
depends:
    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    clientsession-0.9.1.1-763bfd866302839ae7dcaa53517a3160
    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cookie-0.4.1.6-8a746b417cee9e54ae77a0b2d5e8515e
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    mwc-random-0.13.3.2-98468153c4310cd751df6539413688b8
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    shakespeare-2.0.7-423d40cf84610c6e09dcfa0707b6b283
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    wai-extra-3.0.13.1-dbbab62e08152a1a89e4fd5c9bc43b08
    wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
    warp-3.2.1-dece252cc38d42a08927d0fe50612a60
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.4.19-16-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-core/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.4.19
id: yesod-core-1.4.19-1b35f3e0bc5edf244c8b12abed4fd6c1
key: yesod_Kg2K77RtKoK6tKZ5OPMGwx
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Json Yesod.Core.Widget
    Yesod.Core.Internal Yesod.Core.Types Yesod.Core.Unsafe
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.19
hs-libraries: HSyesod-core-1.4.19-Kg2K77RtKoK6tKZ5OPMGwx
depends:
    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    clientsession-0.9.1.1-763bfd866302839ae7dcaa53517a3160
    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
    conduit-extra-1.1.11-c734df1add5fd1001eeb71b770cb5cb3
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cookie-0.4.1.6-8a746b417cee9e54ae77a0b2d5e8515e
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-logger-0.3.18-cd8d51c949646894888975572eea97f1
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    shakespeare-2.0.7-d65cfe041713246ebadd86a7511ba6cd
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    wai-extra-3.0.14.1-5f3982898a5be41036c34bae0277136d
    wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
    warp-3.2.3-e779983be81de2d2755ab5db7108dace
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
